<!--
SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
SPDX-License-Identifier: BSD-2-Clause
-->

# Download

These are the released versions of [uvoxen](index.md) available for download.

## [0.1.1] - 2025-03-12

### Source tarball

- [uvoxen-0.1.1.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.1.tar.gz.asc))

### Python wheel

- [uvoxen-0.1.1-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.1-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.1-py3-none-any.whl.asc))

## [0.1.0] - 2025-03-08

### Source tarball

- [uvoxen-0.1.0.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.0.tar.gz.asc))

### Python wheel

- [uvoxen-0.1.0-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.0-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.0-py3-none-any.whl.asc))

[0.1.0]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.1.0
[0.1.1]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.1.1
